<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array("_8c575917cbaed" . "f1e7efae849394" . "02bff" => base64_decode("U3ViamVjd" . "A=="), "_97ea09a7" . "faf27c52c" . "6eff69773" . "df1d8a" => base64_decode("dGltZXN0YW" . "1w"), "_618a4aeb9fecc4592a4521f3487" . "6fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_9c050c786fc87170" . "cbb84fc6a8b13cb6" => base64_decode("YXR0YWNob" . "WVudC0="), "_44e986c04f41a08b56a383c" . "7b3a88ee2" => base64_decode("c2V" . "uZG" . "Vy"), "_f39f534" . "6e313e4d" . "d1ac3a7b" . "d8032bed" . "a" => base64_decode("c3Vic3RyX" . "2NvbXBhcm" . "U="), "_6e1c717cf3cbf1af982ed74d433" . "6b7f1" => base64_decode("Ym9keS1od" . "G1s"), "_956cd32298a2" . "29f9768f1096f" . "077ace3" => base64_decode("Ym9keS1wbG" . "Fpbg=="), "_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e" => base64_decode("cmVjaXBpZW5" . "0"), "_d706c160e45bf7434fff82a5976f0" . "e19" => base64_decode("YXJyYXlfa2" . "V5cw=="), "_a1e707d" . "02a236da" . "debd15a4" . "5e65ebdb" . "6" => base64_decode("YXR0YWNobWVudC1jb" . "3VudA=="), "_f589476007fa133f457c3ef29d" . "dfa566" => base64_decode("V" . "G" . "8" . "="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_d706c160e45bf7434ff" . "f82a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_a1e707d0" . "2a236dade" . "bd15a45e6" . "5ebdb6"] && $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_f39f5346e313e4dd1" . "ac3a7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_9c050c7" . "86fc8717" . "0cbb84fc" . "6a8b13cb" . "6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_1d6c68a0262e8fa0bed1" . "215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_618a4ae" . "b9fecc45" . "92a4521f" . "34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_f589476" . "007fa133" . "f457c3ef" . "29ddfa56" . "6"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_8c575917cbaedf1e7ef" . "ae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_6e1c717cf3cbf" . "1af982ed74d433" . "6b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_956cd32298a229f9768f1096f077ace" . "3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_97ea09a7faf27c52c6ef" . "f69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_44e986c04f41a08b5" . "6a383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}