<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array("_67a0d624aebcceb0abd5" . "ce56a53ff06f" => base64_decode("ZGF0Z" . "Q=="), "_618a4aeb9fecc4592a452" . "1f34876fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_03b1f0cee835582d1158dc" . "e2678b505c" => base64_decode("U3RhcnRpbmcgaW5" . "mb2NhcHR1cmUgbW" . "FpbCByZWNlaXZlZ" . "CBzdWJzY3JpYmVy"), "_460e1aeb3113a1676ce59a8" . "f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2plY" . "3Q="), "_9b16fa2683095e67d7c8b265a8081" . "d0b" => base64_decode("TWFpbFJlY2VpdmVkRX" . "ZlbnRSZWNlaXZlcg=="), "_c35473364fa7a0502" . "99058f332ec29c1" => base64_decode("ZXhjZXB0aW9" . "u"), "_ced92d7" . "b391285c" . "8a26846f" . "1f4bd312" . "8" => base64_decode("Ym9keV" . "90ZXh0"), "_5d40a2cf1" . "c525fb252b" . "f5599e339f" . "dd0" => base64_decode("Tm8gaW5mb2NhcHR1cmU" . "gcHJvamVjdCB3YXMgaW" . "RlbnRpZmllZCBmb3Igb" . "WFpbDsgc3ViamVjdCAn"), "proj" . "ect_" . "id" => base64_decode("cHJvamV" . "jdF9pZA" . "=="), "_376d30c40857357a4d4cb" . "b1ffaa25817" => base64_decode("dG8" . "="), "_bfda889b74ea561b143" . "25e30e7d75426" => base64_decode("Ym9" . "keV" . "9od" . "G1s"), "_f656816961e8573806141c558b1" . "84fe2" => base64_decode("c3Viam" . "VjdA=="), "_a3d82c5df38e194c9c73e3c" . "cb4223bbc" => base64_decode("ZW1haWx" . "fZGF0YQ" . "=="), "_e608e5b5c4c34a67ba9" . "7ef84c1e16199" => base64_decode("Jw=" . "="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_9b16fa2683" . "095e67d7c8b" . "265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_03b1f0cee8" . "35582d1158d" . "ce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_5d40a2cf1c525fb252bf5599e339fd" . "d0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_e608e5b5c4c34a6" . "7ba97ef84c1e1619" . "9"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_618a4aeb9fecc4592a4521f34" . "876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_376d30c40" . "857357a4d4" . "cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_f656816961e8573806141c558b18" . "4fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_ced92d7b391285c8" . "a26846f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_bfda889b74ea561b1432" . "5e30e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_67a0d624aebcceb0abd" . "5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["proj" . "ect_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_a3d82c5df38e194c9c73e3cc" . "b4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_c35473364fa7a05029" . "9058f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}